package com.ximai.mes.md.service;

import com.ximai.mes.md.domain.MdBrand;

import java.util.List;

/**
 * title:
 * author:ZHT
 * date:2024/1/16
 * description:
 */
public interface IMdBrandService {

    List<MdBrand> selectMdBrandList(MdBrand mdBrand);

    MdBrand selectMdBrandByBrandId(Long brandId);

    String checkCodeUnique(MdBrand mdBrand);

    String checkNameUnique(MdBrand mdBrand);

    int insertMdBrand(MdBrand mdBrand);

    int updateMdBrand(MdBrand mdBrand);

    int deleteMdBrandByBrandId(Long brandId);
//    int deleteMdBrandByBrandIds(Long[] brandIds);
}
